@@ -13,6 +13,7 @@ from pulpcore.plugin.serializers import (
     RepositorySerializer,
     SingleArtifactContentUploadSerializer,
 )
+from pulpcore.plugin.util import get_domain_pk
 
 from pulp_file.app.models import (
     FileAlternateContentSource,
@@ -35,22 +36,16 @@ class FileContentSerializer(SingleArtifactContentUploadSerializer, ContentChecks
 
         data["digest"] = data["artifact"].sha256
 
-        content = FileContent.objects.filter(
-            digest=data["digest"], relative_path=data["relative_path"]
-        )
-
-        if content.exists():
-            content.get().touch()
-
-            raise serializers.ValidationError(
-                _(
-                    "There is already a file content with relative path '{path}' and digest "
-                    "'{digest}'."
-                ).format(path=data["relative_path"], digest=data["digest"])
-            )
-
         return data
 
+    def retrieve(self, validated_data):
+        content = FileContent.objects.filter(
+            digest=validated_data["digest"],
+            relative_path=validated_data["relative_path"],
+            pulp_domain=get_domain_pk(),
+        )
+        return content.first()
+
     class Meta:
         fields = (
             SingleArtifactContentUploadSerializer.Meta.fields
@@ -77,6 +72,7 @@ class FileRepositorySerializer(RepositorySerializer):
         help_text=_("Filename to use for manifest file containing metadata for all the files."),
         default="PULP_MANIFEST",
         required=False,
+        allow_null=True,
     )
 
     class Meta:
@@ -117,6 +113,7 @@ class FilePublicationSerializer(PublicationSerializer):
         help_text=_("Filename to use for manifest file containing metadata for all the files."),
         default="PULP_MANIFEST",
         required=False,
+        allow_null=True,
     )
 
     class Meta:
